@@ -273,24 +273,23 @@
     (bmkp-url :foreground blue :underline t)
     (bmkp-variable-list :foreground green)
     ;;;; calfw
-    (cfw:face-title              :foreground blue                     :weight 'bold :height 2.0 :inherit 'variable-pitch)
-    (cfw:face-header             :foreground (doom-blend blue bg 0.8) :weight 'bold)
-    (cfw:face-sunday             :foreground (doom-blend red bg 0.8)  :weight 'bold)
-    (cfw:face-saturday           :foreground (doom-blend red bg 0.8)  :weight 'bold)
-    (cfw:face-holiday            :background bg-alt :weight 'bold)
-    (cfw:face-grid               :foreground vertical-bar)
-    (cfw:face-periods            :foreground yellow)
-    (cfw:face-toolbar)
-    (cfw:face-toolbar-button-off :foreground base6                    :weight 'bold             :inherit 'variable-pitch)
-    (cfw:face-toolbar-button-on  :foreground blue                     :weight 'bold             :inherit 'variable-pitch)
-    (cfw:face-default-content    :foreground fg)
-    (cfw:face-day-title          :foreground fg                       :weight 'bold)
-    (cfw:face-today-title        :foreground bg  :background blue     :weight 'bold)
-    (cfw:face-default-day                                             :weight 'bold)
-    (cfw:face-today              :weight 'bold)
-    (cfw:face-annotation         :foreground violet)
-    (cfw:face-disable            :foreground grey)
-    (cfw:face-select             :background region)
+    (calfw-annotation-face         :foreground violet)
+    (calfw-day-title-face          :foreground fg                       :weight 'bold)
+    (calfw-default-content-face    :foreground fg)
+    (calfw-default-day-face                                             :weight 'bold)
+    (calfw-disable-face            :foreground grey)
+    (calfw-grid-face               :foreground vertical-bar)
+    (calfw-header-face             :foreground (doom-blend blue bg 0.8) :weight 'bold)
+    (calfw-holiday-face            :background bg-alt :weight 'bold)
+    (calfw-periods-face            :foreground yellow)
+    (calfw-saturday-face           :foreground (doom-blend red bg 0.8)  :weight 'bold)
+    (calfw-sunday-face             :foreground (doom-blend red bg 0.8)  :weight 'bold)
+    (calfw-title-face              :foreground blue                     :weight 'bold :height 2.0 :inherit 'variable-pitch)
+    (calfw-today-face              :weight 'bold)
+    (calfw-today-title-face        :foreground bg  :background blue     :weight 'bold)
+    (calfw-toolbar-button-off-face :foreground base6                    :weight 'bold             :inherit 'variable-pitch)
+    (calfw-toolbar-button-on-face  :foreground blue                     :weight 'bold             :inherit 'variable-pitch)
+    (calfw-toolbar-face)
     ;;;; centaur-tabs
     ((centaur-tabs-default &inherit tab-bar) :box nil)
     ((centaur-tabs-selected &inherit tab-bar-tab) :box nil)
@@ -675,8 +674,8 @@
     (gnus-group-news-6-empty     :inherit 'gnus-group-news-1-empty)
     (gnus-group-mail-low         :inherit 'gnus-group-mail-1 :weight 'normal)
     (gnus-group-mail-low-empty   :inherit 'gnus-group-mail-1-empty)
-    (gnus-group-news-low         :inherit 'gnus-group-mail-1 :foreground base5)
     (gnus-group-news-low-empty   :inherit 'gnus-group-news-low :weight 'normal)
+    (gnus-group-news-low         :inherit 'gnus-group-mail-1 :foreground base5)
     (gnus-header-content         :inherit 'message-header-other)
     (gnus-header-from            :inherit 'message-header-other)
     (gnus-header-name            :inherit 'message-header-name)
